#!/usr/bin/ruby -Ku
#
# mmon
#
# Copyright (c) 2007 sanpo
#
# This program is free software.
# You can redistribute it and/or modify it under the terms of the GPL.

require 'mmon/item'
require 'mmon/util'
require 'mmon/memory'
require 'mmon/bar_graph'

class ItemMem < Item
    NAME = 'Memory'

    @@color_used = Color.new(1.0, 0.0, 0.0, 0.9)
    @@color_buffers = Color.new(0.0, 1.0, 0.0, 0.9)
    @@color_cached = Color.new(0.0, 0.0, 1.0, 0.9)
    @@color_paged = Color.new(1.0, 0.0, 1.0, 0.9)

    def initialize(parent = nil)
        super(parent)

        @interval = 1.0
        @use_bg = true
        @use_fg = true
        self.set_item_size(72, 32)

        @mem = Memory.new

        @bar_mem = BarGraph.new(72 - 4, 32 / 2 - 3)
        @bar_mem.color(@@color_used, @@color_buffers, @@color_cached)
        @bar_mem.position(2, 2)

        @bar_swap = BarGraph.new(72 - 4, 32 / 2 - 3)
        @bar_swap.color(@@color_paged)
        @bar_swap.position(2, 32 / 2 + 1)
    end

    private

    def render_mask(cc, w, h)
        Util.simple_bg2(cc, w, h)
        Util.simple_fg2(cc, w, h)
    end

    def render_bg(cc, w, h)
        Util.simple_bg2(cc, w, h)
    end

    def render_fg(cc, w, h)
        Util.simple_fg2(cc, w, h)
    end

    def render(cc, w, h)
        @bar_mem.render(cc)
        @bar_swap.render(cc)
    end

    def prepare
        @mem.read

        mem_total = @mem.mem_total

        used = @mem.mem_used.to_f / mem_total
        buffers = @mem.mem_buffers.to_f / mem_total
        cached = @mem.mem_cached.to_f / mem_total

        @bar_mem.value(used, buffers, cached)


        paged = @mem_paged.to_f / @mem.swap_total

        @bar_swap.value(paged)

        return true
    end
end

if __FILE__ == $0
    item = ItemMem.new
    item.show

    Gtk::main()
end
